@@ -9,7 +9,7 @@
 #'  function, containing values for the 'x' coordinates as a column (labeled as such).
 #' @param achro should a point be plotted at the origin (defaults to \code{TRUE})?
 #' @param labels plot verticy labels? Defaults to \code{TRUE}.
-#' @param lab.cex character expansion factor for category labels when \code{labels = TRUE}).
+#' @param labels.cex character expansion factor for category labels when \code{labels = TRUE}).
 #' @param achrosize size of the point at the origin when \code{achro = TRUE} (defaults to \code{0.8}).
 #' @param achrocol color of the point at the origin \code{achro = TRUE} (defaults to \code{'grey'}).
 #' @param out.lwd,out.lcol,out.lty graphical parameters for the segment.
@@ -36,7 +36,7 @@
 #'    81 - 118.
 
 diplot <- function(didata, labels = TRUE, achro = TRUE, achrocol = 'grey', achrosize = 0.8, 
-                    lab.cex = 1, out.lwd = 1, out.lcol = 'black', out.lty = 1, 
+                    labels.cex = 1, out.lwd = 1, out.lcol = 'black', out.lty = 1, 
                     margins = c(1, 1, 2, 2), square = TRUE,...){ 
   
   par(mar=margins)
@@ -70,8 +70,8 @@ diplot <- function(didata, labels = TRUE, achro = TRUE, achrocol = 'grey', achro
   
 # Add text (coloured points better as in tcsplot?)
    if(isTRUE(labels)){
-     text('S', x = -0.76, y = 0, xpd = TRUE, cex = lab.cex)
-     text('L', x = 0.76, y = 0, xpd = TRUE, cex = lab.cex)
+     text('S', x = -0.76, y = 0, xpd = TRUE, cex = labels.cex)
+     text('L', x = 0.76, y = 0, xpd = TRUE, cex = labels.cex)
    }
   
 }
\ No newline at end of file
