@@ -1,18 +1,18 @@
-#' Modelling spectral sensitivity
+#' modeling spectral sensitivity
 #'
 #' Models spectral sensitivity (with oil droplets; optional) based on peak cone sensitivity
 #' according to the models of Govardovskii et al. (2000) and Hart & Vorobyev (2005).
 #'
-#' @param peaksense (required) a vector with peak sensitivities for the cones to
+#' @param peaksens (required) a vector with peak sensitivities for the cones to
 #' model.
 #' @param range a vector of length 2 for the range over which to calculate the spectral 
 #' sensitivities (defaults to 300nm to 700nm).
-#' @param lambdacut a vector of same length as peaksense that lists the cut-off wavelength
+#' @param lambdacut a vector of same length as peaksens that lists the cut-off wavelength
 #' value for oil droplets. Needs either \code{Bmid} or \code{oiltype} to also be entered.
 #' See Hart and Vorobyev (2005).
-#' @param Bmid a vector of same length as peaksense that lists the gradient of line 
+#' @param Bmid a vector of same length as peaksens that lists the gradient of line 
 #' tangent to the absorbance spectrum of the oil droplets. See Hart and Vorobyev (2005). 
-#' @param oiltype a list of same length as peaksense that lists the oil droplet types
+#' @param oiltype a list of same length as peaksens that lists the oil droplet types
 #' (currently accepts only "T", C", "Y", "R", "P") when Bmid is not known. Calculates
 #' Bmid based on the regression equations found in Hart ad Vorobyev (2005).
 #' @param beta logical. If \code{TRUE} the sensitivities will include the beta peak
@@ -42,7 +42,7 @@
 #' 
 #' @references Govardovskii VI, Fyhrquist N, Reuter T, Kuzmin DG and Donner K. 2000. 
 #' In search of the visual pigment template. Visual Neuroscience 17:509-528
-#' @references Hart NS, and Vorobyev M. 2005. Modelling oil droplet absorption
+#' @references Hart NS, and Vorobyev M. 2005. modeling oil droplet absorption
 #' spectra and spectral sensitivities of bird cone photoreceptors. Journal of
 #' Comparative Physiology A. 191: 381-392
 #' @references Hart NS, Partridge JC, Cuthill IC, Bennett AT (2000) Visual pigments, 
@@ -52,12 +52,12 @@
 
 
 
-sensmodel <- function(peaksense, range = c(300, 700), lambdacut = NULL, Bmid = NULL, 
+sensmodel <- function(peaksens, range = c(300, 700), lambdacut = NULL, Bmid = NULL, 
 		             oiltype = NULL, beta = TRUE, om = NULL, integrate = TRUE) {
 
 if (!is.null(lambdacut)){
  if (is.null(Bmid) & is.null(oiltype)) stop ("Bmid or oiltype must be included when including a lambdacut vector", call.=FALSE)
- if (length(lambdacut) != length(peaksense)) stop ("lambdacut must be same length as peaksense", call.=FALSE)
+ if (length(lambdacut) != length(peaksens)) stop ("lambdacut must be same length as peaksens", call.=FALSE)
 }
 
 if(!is.null(Bmid) & is.null(lambdacut)) # Change once oil type corrected
@@ -67,19 +67,19 @@ if (!is.null(lambdacut) & !is.null(Bmid) & !is.null(oiltype))
   stop('only 2 of lambdacut, Bmid, and oiltype can be provided')
 
 
-sensecurves <- matrix(ncol = length(peaksense)+1,nrow = (range[2]-range[1]+1))
+sensecurves <- matrix(ncol = length(peaksens)+1,nrow = (range[2]-range[1]+1))
 sensecurves[,1] <- c(range[1]:range[2])
 
 
 
-for (i in 1: length(peaksense)){
+for (i in 1: length(peaksens)){
 
   #Sensitivities w/o oil droplets
-  peak <- 1/(exp(69.7*(.8795+.0459*exp(-(peaksense[i]-range[1])^2/11940)-(peaksense[i]/(range[1]:range[2]))))
-  +exp(28*(.922-peaksense[i]/(range[1]:range[2])))+exp(-14.9*(1.104-(peaksense[i]/(range[1]:range[2]))))+.674)
+  peak <- 1/(exp(69.7*(.8795+.0459*exp(-(peaksens[i]-range[1])^2/11940)-(peaksens[i]/(range[1]:range[2]))))
+  +exp(28*(.922-peaksens[i]/(range[1]:range[2])))+exp(-14.9*(1.104-(peaksens[i]/(range[1]:range[2]))))+.674)
 
   betaband <- 0.26*exp(-(((range[1]:range[2])
-  -(189+0.315*peaksense[i]))/(-40.5+0.195*peaksense[i]))^2)
+  -(189+0.315*peaksens[i]))/(-40.5+0.195*peaksens[i]))^2)
 
   if (beta==TRUE) peak <- peak + betaband
 peak <- peak/max(peak)
@@ -145,7 +145,7 @@ sensecurves[, (i+1)] <- peak
   }
 
 sensecurves <- data.frame(sensecurves)
-names(sensecurves) <- c('wl',paste('lmax',peaksense,sep=''))
+names(sensecurves) <- c('wl',paste('lmax',peaksens,sep=''))
 #sensecurves <- as.rspec(sensecurves)
 class(sensecurves) <- c('rspec', 'sensmod', 'data.frame')
 
