@@ -9,7 +9,7 @@
 #'  as columns (labeled as such).
 #' @param achro should a point be plotted at the origin (defaults to \code{TRUE})?.
 #' @param labels plot verticy labels? Defaults to \code{TRUE}.
-#' @param cex.labels character expansion factor for category labels when \code{labels = TRUE}).
+#' @param labels.cex character expansion factor for category labels when \code{labels = TRUE}).
 #' @param achrosize size of the point at the origin when \code{achro = TRUE} (defaults to 0.8).
 #' @param achrocol color of the point at the origin \code{achro = TRUE} (defaults to \code{'grey'}).
 #' @param out.lwd,out.lcol,out.lty graphical parameters for the plot outline.
@@ -38,7 +38,7 @@
 #'  Journal of comparative physiology, 139(3), 165-176.
 
 triplot <- function(tridata, labels = TRUE, achro = TRUE, achrocol = 'grey', achrosize = 0.8, 
-                     cex.labels = 1, out.lwd = 1, out.lcol = 'black', out.lty = 1, 
+                     labels.cex = 1, out.lwd = 1, out.lcol = 'black', out.lty = 1, 
                      margins = c(1, 1, 2, 2), square = TRUE, ...){ 
   
   par(mar=margins)
@@ -88,9 +88,9 @@ do.call(points, arg)
   
 # Add text (coloured points better as in tcsplot?)
   if(isTRUE(labels)){
-    text('M', x = -0.76, y = -0.39, xpd = TRUE, cex = cex.labels)
-    text('S', x = 0, y = 0.88, xpd = TRUE, cex = cex.labels)
-    text('L', x = 0.76, y = -0.39, xpd = TRUE, cex = cex.labels)
+    text('M', x = -0.76, y = -0.39, xpd = TRUE, cex = labels.cex)
+    text('S', x = 0, y = 0.88, xpd = TRUE, cex = labels.cex)
+    text('L', x = 0.76, y = -0.39, xpd = TRUE, cex = labels.cex)
   }
   
 }
\ No newline at end of file
